.. _thema:

THEMA
=============
.. admonition:: Acronym!

   :strong:`T`\opological :strong:`H`\yperparameter :strong:`E`\valuation :strong:`M`\apping :strong:`A`\lgorithm

Welcome to THEMA. Browse the API or dive into the multiverse when you're ready to build.

.. grid:: 1 2 2 2
   :gutter: 4
   :padding: 2 2 0 0

   .. grid-item-card:: Systems (Inner + Outer)
      :class-card: intro-card
      :shadow: md

      Clean, encode, impute data, then embed it.

      +++
      .. button-ref:: systems
         :ref-type: ref
         :click-parent:
         :color: secondary
         :expand:

   .. grid-item-card:: Universe
      :class-card: intro-card
      :shadow: md

      Build graphs, compare with curvature distances, and select representatives.

      +++
      .. button-ref:: thema-universe
         :ref-type: ref
         :click-parent:
         :color: secondary
         :expand:


.. toctree::
   :maxdepth: 3
   :hidden:

   configuration
   multiverse/thema.multiverse
   expansion/thema.expansion

.. raw:: html

   <hr style="border: none; border-top: 2px solid #007bff; margin: 20px 0;">

Further Reading
---------------

* :ref:`User Guides <user_guide>`
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
